@@ -20,7 +20,7 @@ from typing import TYPE_CHECKING, Any, Set, Union
 
 from robot.utils import timestr_to_secs  # type: ignore
 
-from ..utils import get_variable_value, logger
+from ..utils import SettingsStack, get_variable_value, logger
 from ..utils.data_types import DelayedKeyword, HighLightElement
 
 if TYPE_CHECKING:
@@ -43,19 +43,27 @@ class LibraryComponent:
 
     @property
     def timeout(self) -> float:
-        return self.library.timeout
+        return self.library.timeout_stack.get()
 
-    @timeout.setter
-    def timeout(self, value: float):
-        self.library.timeout = value
+    @property
+    def timeout_stack(self) -> SettingsStack:
+        return self.library.timeout_stack
+
+    @timeout_stack.setter
+    def timeout_stack(self, stack: SettingsStack):
+        self.library.timeout_stack = stack
 
     @property
     def retry_assertions_for(self) -> float:
-        return self.library.retry_assertions_for
+        return self.library.retry_assertions_for_stack.get()
 
-    @retry_assertions_for.setter
-    def retry_assertions_for(self, value: float):
-        self.library.retry_assertions_for = value
+    @property
+    def retry_assertions_for_stack(self) -> SettingsStack:
+        return self.library.retry_assertions_for_stack
+
+    @retry_assertions_for_stack.setter
+    def retry_assertions_for_stack(self, stack: SettingsStack):
+        self.library.retry_assertions_for_stack = stack
 
     @property
     def unresolved_promises(self):
@@ -79,19 +87,19 @@ class LibraryComponent:
 
     @property
     def screenshots_output(self):
-        return self.browser_output / "screenshot"
+        return self.library.screenshots_output
 
     @property
     def video_output(self):
-        return self.browser_output / "video"
+        return self.library.video_output
 
     @property
     def traces_output(self):
-        return self.browser_output / "traces"
+        return self.library.traces_output
 
     @property
     def state_file(self):
-        return self.browser_output / "state"
+        return self.library.state_file
 
     def get_timeout(self, timeout: Union[timedelta, None]) -> float:
         return self.library.get_timeout(timeout)
@@ -138,11 +146,15 @@ class LibraryComponent:
 
     @property
     def strict_mode(self) -> bool:
-        return self.library.strict_mode
+        return self.library.strict_mode_stack.get()
 
-    @strict_mode.setter
-    def strict_mode(self, mode: bool):
-        self.library.strict_mode = mode
+    @property
+    def strict_mode_stack(self) -> SettingsStack:
+        return self.library.strict_mode_stack
+
+    @strict_mode_stack.setter
+    def strict_mode_stack(self, stack: SettingsStack):
+        self.library.strict_mode_stack = stack
 
     def parse_run_on_failure_keyword(
         self, keyword_name: Union[str, None]
@@ -167,12 +179,18 @@ class LibraryComponent:
     def presenter_mode(self, selector, strict):
         if self.library.presenter_mode:
             mode = self.get_presenter_mode
-            self.library.hover(selector, strict)
-            self.library.highlight_elements(
-                selector,
-                duration=mode["duration"],
-                width=mode["width"],
-                style=mode["style"],
-                color=mode["color"],
-            )
-            sleep(mode["duration"].seconds)
+            try:
+                self.library.scroll_to_element(selector)
+                self.library.highlight_elements(
+                    selector,
+                    duration=mode["duration"],
+                    width=mode["width"],
+                    style=mode["style"],
+                    color=mode["color"],
+                )
+            except Exception as error:
+                selector = self.library.record_selector(f'"{selector}" failure')
+                logger.debug(f"On presenter more supress {error}")
+            else:
+                sleep(mode["duration"].seconds)
+        return selector
