@@ -17,13 +17,13 @@ import os
 from collections.abc import Iterable
 from datetime import timedelta
 from pathlib import Path
-from typing import List, Optional, Union
+from typing import Dict, List, Optional, Union
 
 from robot.utils import get_link_path  # type: ignore
 
 from ..base import LibraryComponent
 from ..generated.playwright_pb2 import Request
-from ..utils import keyword, logger
+from ..utils import Scope, keyword, logger
 from ..utils.data_types import BoundingBox, Permission, ScreenshotFileTypes
 
 
@@ -32,14 +32,20 @@ class Control(LibraryComponent):
 
     @keyword(tags=("Setter", "BrowserControl"))
     def go_forward(self):
-        """Navigates to the next page in history."""
+        """Navigates to the next page in history.
+
+        [https://forum.robotframework.org/t//4290|Comment >>]
+        """
         with self.playwright.grpc_channel() as stub:
             response = stub.GoForward(Request.Empty())
             logger.info(response.log)
 
     @keyword(tags=("Setter", "BrowserControl"))
     def go_back(self):
-        """Navigates to the previous page in history."""
+        """Navigates to the previous page in history.
+
+        [https://forum.robotframework.org/t//4289|Comment >>]
+        """
         with self.playwright.grpc_channel() as stub:
             response = stub.GoBack(Request.Empty())
             logger.info(response.log)
@@ -48,10 +54,11 @@ class Control(LibraryComponent):
     def go_to(self, url: str, timeout: Optional[timedelta] = None):
         """Navigates to the given ``url``.
 
-        ``url`` <str> URL to be navigated to.
+        | =Arguments= | =Description= |
+        | ``url`` | <str> URL to be navigated to. |
+        | ``timeout`` | <str> time to wait page to load. If not defined will use the library default timeout. |
 
-        ``timeout`` <str> time to wait page to load. If not defined
-        will use the library default timeout.
+        [https://forum.robotframework.org/t//4291|Comment >>]
         """
         with self.playwright.grpc_channel() as stub:
             response = stub.GoTo(
@@ -95,44 +102,17 @@ class Control(LibraryComponent):
     ) -> str:
         """Takes a screenshot of the current window or element and saves it to disk.
 
-        ``filename`` Filename into which to save. The file will be saved into the robot framework
-         ${OUTPUTDIR}/browser/screenshot directory by default, but it can overwritten by providing
-         custom path or filename. String ``{index}`` in filename will be replaced with a rolling
-         number. Use this to not override filenames. If filename equals to EMBED (case insensitive),
-         then screenshot is embedded as Base64 image to the log.html. The image is saved temporally
-         to the disk and warning is displayed if removing the temporary file fails.
-
-         The ${OUTPUTDIR}/browser/ is removed at the first suite startup.
-
-        ``selector`` Take a screenshot of the element matched by selector.
-        See the `Finding elements` section for details about the selectors.
-        If not provided take a screenshot of current viewport.
-
-        ``fullPage`` When True, takes a screenshot of the full scrollable page,
-        instead of the currently visible viewport. Defaults to False.
-
-        ``fileType`` <"png"|"jpeg"> Specify screenshot type, defaults to png.
-
-        ``quality`` The quality of the image, between 0-100. Not applicable to png images.
-
-        ``timeout`` Maximum time how long taking screenshot can last, defaults to library timeout.
-        Supports Robot Framework time format, like 10s or 1 min, pass 0 to disable timeout.
-        The default value can be changed by using the `Set Browser Timeout` keyword.
-
-        ``crop`` Crops the taken screenshot to the given box. It takes same dictionary as returned from `Get BoundingBox`.
-        Cropping only works on page screenshot, so if no selector is given.
-
-        ``disableAnimations`` When set to ``True``, stops CSS animations, CSS transitions and Web Animations.
-        Animations get different treatment depending on their duration:
-         - finite animations are fast-forwarded to completion, so they'll fire transitionend event.
-         - infinite animations are canceled to initial state, and then played over after the screenshot.
-
-        ``mask`` Specify selectors that should be masked when the screenshot is taken.
-        Masked elements will be overlayed with a pink box ``#FF00FF`` that completely covers its bounding box.
-        Arguemnt can take a single selector string or a list of selector strings if multiple different elements should be masked.
-
-        ``omitBackground`` Hides default white background and allows capturing screenshots with transparency.
-        Not applicable to jpeg images.
+        | =Arguments= | =Description= |
+        | ``filename`` | Filename into which to save. The file will be saved into the robot framework  ${OUTPUTDIR}/browser/screenshot directory by default, but it can overwritten by providing  custom path or filename. String ``{index}`` in filename will be replaced with a rolling  number. Use this to not override filenames. If filename equals to EMBED (case insensitive),  then screenshot is embedded as Base64 image to the log.html. The image is saved temporally  to the disk and warning is displayed if removing the temporary file fails. The ${OUTPUTDIR}/browser/ is removed at the first suite startup. |
+        | ``selector`` | Take a screenshot of the element matched by selector. See the `Finding elements` section for details about the selectors. If not provided take a screenshot of current viewport. |
+        | ``fullPage`` | When True, takes a screenshot of the full scrollable page, instead of the currently visible viewport. Defaults to False. |
+        | ``fileType`` | <"png"|"jpeg"> Specify screenshot type, defaults to png. |
+        | ``quality`` | The quality of the image, between 0-100. Not applicable to png images. |
+        | ``timeout`` | Maximum time how long taking screenshot can last, defaults to library timeout. Supports Robot Framework time format, like 10s or 1 min, pass 0 to disable timeout. The default value can be changed by using the `Set Browser Timeout` keyword. |
+        | ``crop`` | Crops the taken screenshot to the given box. It takes same dictionary as returned from `Get BoundingBox`. Cropping only works on page screenshot, so if no selector is given. |
+        | ``disableAnimations`` | When set to ``True``, stops CSS animations, CSS transitions and Web Animations. Animations get different treatment depending on their duration:  - finite animations are fast-forwarded to completion, so they'll fire transitionend event.  - infinite animations are canceled to initial state, and then played over after the screenshot. |
+        | ``mask`` | Specify selectors that should be masked when the screenshot is taken. Masked elements will be overlayed with a pink box ``#FF00FF`` that completely covers its bounding box. Argument can take a single selector string or a list of selector strings if multiple different elements should be masked. |
+        | ``omitBackground`` | Hides default white background and allows capturing screenshots with transparency. Not applicable to jpeg images. |
 
         Keyword uses strict mode if selector is defined. See `Finding elements` for more details
         about strict mode.
@@ -142,6 +122,8 @@ class Control(LibraryComponent):
         | `Take Screenshot`   selector=id=username_field    # Captures element in image
         | # Takes screenshot with jpeg extension, defines image quality and timeout how long taking screenhost should last
         | `Take Screenshot`   fullPage=True    fileType=jpeg    quality=50    timeout=10s
+
+        [https://forum.robotframework.org/t//4337|Comment >>]
         """
         if self._is_embed(filename):
             logger.debug("Embedding image to log.html.")
@@ -223,21 +205,24 @@ class Control(LibraryComponent):
         return True if filename.upper() == "EMBED" else False
 
     @keyword(tags=("Setter", "Config"))
-    def set_browser_timeout(self, timeout: timedelta) -> str:
+    def set_browser_timeout(
+        self, timeout: timedelta, scope: Scope = Scope.Suite
+    ) -> str:
         """Sets the timeout used by most input and getter keywords.
 
-        ``timeout`` Timeout of it is for current playwright context
-        and for new contexts. Supports Robot Framework
-        [https://robotframework.org/robotframework/latest/RobotFrameworkUserGuide.html#time-format|time format]
-        . Returns the previous value of the timeout.
+        | =Arguments= | =Description= |
+        | ``timeout`` | Timeout of it is for current playwright context and for new contexts. Supports Robot Framework [https://robotframework.org/robotframework/latest/RobotFrameworkUserGuide.html#time-format|time format] . Returns the previous value of the timeout. |
+        | ``scope``   | Scope defines the live time of that setting. Available values are ``Global``, ``Suite`` or ``Test``/``Task``. See `Scope Settings` for more details. |
 
         Example:
         | ${old_timeout} =    `Set Browser Timeout`    1m 30 seconds
         | Click     //button
         | `Set Browser Timeout`    ${old_timeout}
+
+        [https://forum.robotframework.org/t//4328|Comment >>]
         """
         old_timeout = self.millisecs_to_timestr(self.timeout)
-        self.timeout = self.convert_timeout(timeout)
+        self.timeout_stack.set(self.convert_timeout(timeout), scope)
         try:
             with self.playwright.grpc_channel() as stub:
                 response = stub.SetTimeout(Request().Timeout(timeout=self.timeout))
@@ -250,16 +235,20 @@ class Control(LibraryComponent):
         return old_timeout
 
     @keyword(tags=("Setter", "Config"))
-    def set_retry_assertions_for(self, timeout: timedelta) -> str:
+    def set_retry_assertions_for(
+        self, timeout: timedelta, scope: Scope = Scope.Suite
+    ) -> str:
         """Sets the timeout used in retrying assertions when they fail.
 
-        `Set Browser timeout` controls how long Playwright will perform
-        waiting in the node side, assertion retry will determine how long
-        Browser library will retry the playwright operation. Generally
-        assertion timeout should be longer than the timeout set by
-        `Set Browser timeout`.
+        | =Arguments= | =Description= |
+        | ``timeout`` | Assertion retry timeout will determine how long Browser library will retry an assertion to be true. |
+        | ``scope``   | Scope defines the live time of that setting. Available values are ``Global``, ``Suite`` or ``Test``/``Task``. See `Scope` for more details. |
 
-        Returns the previous value of the assertion retry.
+        The other keyword `Set Browser timeout` controls how long Playwright
+        will perform waiting in the node side for Elements to fulfill the
+        requirements of the specific keyword.
+
+        Returns the previous value of the assertion retry timeout.
 
         Example:
         | `Set Browser Timeout`    10 seconds
@@ -269,11 +258,44 @@ class Control(LibraryComponent):
 
         Example waits 10 seconds on Playwright to get the page title and library
         will retry 30 seconds to make sure that title is correct.
+
+        [https://forum.robotframework.org/t//4331|Comment >>]
         """
         old_retry_assertions_for = self.millisecs_to_timestr(self.retry_assertions_for)
-        self.retry_assertions_for = self.convert_timeout(timeout)
+        self.retry_assertions_for_stack.set(self.convert_timeout(timeout), scope)
         return old_retry_assertions_for
 
+    @keyword(tags=("Setter", "Config"))
+    def show_keyword_banner(
+        self, show: bool = True, style: str = ""
+    ) -> Dict[str, Union[None, bool, str]]:
+        """Controls if the keyword banner is shown on page or not.
+
+        Keyword call banner is a css overlay that shows the currently executed keyword directly on page.
+        This is useful for debugging and for showing the test execution on video recordings.
+        By default, the banner is not shown on page except when running in presenter mode.
+
+        The banner can be controlled by an import setting of Browser library. (see `Importing` section)
+
+        | =Arguments= | =Description= |
+        | ``show`` | If `True` banner is shown on page. If `False` banner is not shown on page. If `None` banner is shown on page only when running in presenter mode. |
+        | ``style`` | Additional css styles to be applied to the banner. These styles are css settings and may override the existing ones for the banner. |
+
+
+        Example:
+        | Show Keyword Banner     True    top: 5px; bottom: auto; left: 5px; background-color: #00909077; font-size: 9px; color: black;   # Show banner on top left corner with custom styles
+        | Show Keyword Banner     False   # Hide banner
+
+        [https://forum.robotframework.org/t//4716|Comment >>]
+        """
+        original_state = self.library.show_keyword_call_banner
+        original_style = self.library.keyword_call_banner_add_style
+        self.library.show_keyword_call_banner = show
+        self.library.keyword_call_banner_add_style = style
+        if not show:
+            self.library.set_keyword_call_banner()
+        return {"show": original_state, "style": original_style}
+
     @keyword(tags=("Setter", "BrowserControl"))
     def set_viewport_size(self, width: int, height: int):
         """Sets current Pages viewport size to specified dimensions.
@@ -288,9 +310,11 @@ class Control(LibraryComponent):
         so you should set the viewport size before navigating to
         the page with `New Context` before opening the page itself.
 
-        ``width`` Sets the width size.
+        | =Arguments= | =Description= |
+        | ``width`` | Sets the width size. |
+        | ``height`` | Sets the height size. |
 
-        ``height`` Sets the height size.
+        [https://forum.robotframework.org/t//4333|Comment >>]
         """
         with self.playwright.grpc_channel() as stub:
             response = stub.SetViewportSize(
@@ -302,8 +326,10 @@ class Control(LibraryComponent):
     def set_offline(self, offline: bool = True):
         """Toggles current Context's offline emulation.
 
-        ``offline`` Toggles the offline mode. Set to False to switch back
-        to online mode. Defaults to True.
+        | =Arguments= | =Description= |
+        | ``offline`` | Toggles the offline mode. Set to False to switch back to online mode. Defaults to True. |
+
+        [https://forum.robotframework.org/t//4330|Comment >>]
         """
         with self.playwright.grpc_channel() as stub:
             response = stub.SetOffline(Request().Bool(value=offline))
@@ -319,10 +345,17 @@ class Control(LibraryComponent):
         Accuracy of the location must be positive number and defaults to 0. When
         creating context, grant ``geolocation`` permission for pages to read its geolocation.
 
+        | =Arguments= | =Description= |
+        | ``latitude`` | Latitude between -90 and 90. |
+        | ``longitude`` | Longitude between -180 and 180. |
+        | ``accuracy`` | Non-negative accuracy value. Defaults to 0. |
+
         Example:
         | ${permissions} =    Create List    geolocation
         | `New Context`    permissions=${permissions}
         | `Set Geolocation`    60.173708, 24.982263    3    # Points to Korkeasaari in Helsinki.
+
+        [https://forum.robotframework.org/t//4329|Comment >>]
         """
         geolocation_dict = {"latitude": latitude, "longitude": longitude}
         if accuracy:
@@ -335,7 +368,10 @@ class Control(LibraryComponent):
 
     @keyword(tags=("Setter", "BrowserControl"))
     def reload(self):
-        """Reloads current active page."""
+        """Reloads current active page.
+
+        [https://forum.robotframework.org/t//4317|Comment >>]
+        """
         with self.playwright.grpc_channel() as stub:
             response = stub.Reload(Request().Empty())
             logger.info(response.log)
@@ -344,13 +380,15 @@ class Control(LibraryComponent):
     def grant_permissions(self, *permissions: Permission, origin: Optional[str] = None):
         """Grants permissions to the current context.
 
-        ```permissions``` is a list of permissions to grant.
-        Permissions can be one of the following:
-        geolocation, notifications, camera, microphone,
+        | =Arguments= | =Description= |
+        | ``permissions`` | is a list of permissions to grant. Permissions can be one of the following: geolocation, notifications, camera, microphone, |
+        | ``origin`` | The origin to grant permissions to, e.g. "https://example.com". |
 
         Example:
         | `New Context`
         | `Grant Permissions`    geolocation
+
+        [https://forum.robotframework.org/t//4292|Comment >>]
         """
         with self.playwright.grpc_channel() as stub:
             response = stub.GrantPermissions(
@@ -362,7 +400,10 @@ class Control(LibraryComponent):
 
     @keyword(tags=("Setter", "BrowserControl"))
     def clear_permissions(self):
-        """Clears all permissions from the current context."""
+        """Clears all permissions from the current context.
+
+        [https://forum.robotframework.org/t//4236|Comment >>]
+        """
         with self.playwright.grpc_channel() as stub:
             response = stub.ClearPermissions(Request().Empty())
             logger.info(response.log)
