@@ -28,6 +28,8 @@ class Devices(LibraryComponent):
         See Playwright's
         [https://github.com/microsoft/playwright/blob/master/packages/playwright-core/src/server/deviceDescriptorsSource.json|deviceDescriptorsSource.json]
         for a formatted list.
+
+        [https://forum.robotframework.org/t//4268|Comment >>]
         """
         with self.playwright.grpc_channel() as stub:
             response = stub.GetDevices(Request().Empty())
@@ -38,9 +40,8 @@ class Devices(LibraryComponent):
     def get_device(self, name: str) -> Dict:
         """Get a single device descriptor with name exactly matching name.
 
-        ``name`` Given name of the requested device. See Playwright's
-        [https://github.com/Microsoft/playwright/blob/master/src/server/deviceDescriptors.ts | deviceDescriptors.ts]
-        for a formatted list.
+        | =Arguments= | =Description= |
+        | ``name`` | Given name of the requested device. See Playwright's [https://github.com/microsoft/playwright/blob/master/packages/playwright-core/src/server/deviceDescriptorsSource.json|deviceDescriptorsSource.json] for a formatted list. |
 
         Allows a concise syntax to set website testing values to exact matches of specific
         mobile devices.
@@ -53,6 +54,8 @@ class Devices(LibraryComponent):
         | `New Context`         &{device}
         | `New Page`
         | `Get Viewport Size`   # returns { "width": 375, "height": 812 }
+
+        [https://forum.robotframework.org/t//4267|Comment >>]
         """
         with self.playwright.grpc_channel() as stub:
             response = stub.GetDevice(Request().Device(name=name))
