@@ -15,11 +15,13 @@
 import json
 import time
 from datetime import timedelta
-from typing import Dict, Optional, Union
+from typing import Any, Dict, Optional, Union
+
+from robot.libraries.BuiltIn import BuiltIn  # type: ignore
 
 from ..base import LibraryComponent
 from ..generated.playwright_pb2 import Request
-from ..utils import ElementState, keyword, logger
+from ..utils import ConditionInputs, ElementState, keyword, logger
 
 
 class Waiter(LibraryComponent):
@@ -42,26 +44,19 @@ class Waiter(LibraryComponent):
 
         If the selector doesn't satisfy the condition within the timeout the keyword will FAIL.
 
-        ``selector`` Selector of the corresponding object.
-        See the `Finding elements` section for details about the selectors.
-
-        ``state`` See `ElementState` for explanation.
-
-        Note that element without any content or with display:none has an empty bounding box
-        and is not considered visible.
-
-        ``timeout`` uses default timeout from library if not set.
-
-        ``message`` overrides the default error message. The ``message``
-        argument accepts `{selector}`, `{function}`, and `{timeout}`
-        [https://docs.python.org/3/library/stdtypes.html#str.format|format] options.
-        The `{function}` formatter is same ``state`` argument value.
+        | =Arguments= | =Description= |
+        | ``selector`` | Selector of the corresponding object. See the `Finding elements` section for details about the selectors. |
+        | ``state`` | See `ElementState` for explanation. |
+        | ``timeout`` | uses default timeout from library if not set. |
+        | ``message`` | overrides the default error message. The ``message`` argument accepts `{selector}`, `{function}`, and `{timeout}` [https://docs.python.org/3/library/stdtypes.html#str.format|format] options. The `{function}` formatter is same ``state`` argument value. |
 
         Keyword uses strict mode, see `Finding elements` for more details about strict mode.
 
         Example:
         | `Wait For Elements State`    //h1    visible    timeout=2 s
         | `Wait For Elements State`    //hi    focused    1s
+
+        [https://forum.robotframework.org/t/comments-for-wait-for-elements-state/4345|Comment >>]
         """
         timeout_as_str = self.millisecs_to_timestr(self.get_timeout(timeout))
         funct = {
@@ -142,22 +137,12 @@ class Waiter(LibraryComponent):
     ):
         """Polls JavaScript expression or function in browser until it returns a (JavaScript) truthy value.
 
-        ``function`` A valid javascript function or a javascript function body. For example
-        ``() => true`` and ``true`` will behave similarly.
-
-        ``selector`` Selector to resolve and pass to the JavaScript function. This will be the first
-        argument the function receives. If given a selector a function is necessary, with an argument
-        to capture the elementhandle. For example ``(element) => document.activeElement === element``
-        See the `Finding elements` section for details about the selectors.
-
-        ``polling`` Default polling value of "raf" polls in a callback for ``requestAnimationFrame``.
-        Any other value for polling will be parsed as a robot framework time for interval between polls.
-
-        ``timeout`` Uses default timeout of 10 seconds if not set.
-
-        ``message`` overrides the default error message. The ``message``
-        argument accepts `{selector}`, `{function}`, and `{timeout}`
-        [https://docs.python.org/3/library/stdtypes.html#str.format|format] options.
+        | =Arguments= | =Description= |
+        | ``function`` | A valid javascript function or a javascript function body. For example ``() => true`` and ``true`` will behave similarly. |
+        | ``selector`` | Selector to resolve and pass to the JavaScript function. This will be the first argument the function receives. If given a selector a function is necessary, with an argument to capture the elementhandle. For example ``(element) => document.activeElement === element`` See the `Finding elements` section for details about the selectors. |
+        | ``polling`` | Default polling value of "raf" polls in a callback for ``requestAnimationFrame``. Any other value for polling will be parsed as a robot framework time for interval between polls. |
+        | ``timeout`` | Uses default timeout of the library if not set. |
+        | ``message`` | overrides the default error message. The ``message`` argument accepts `{selector}`, `{function}`, and `{timeout}` [https://docs.python.org/3/library/stdtypes.html#str.format|format] options. |
 
         Keyword uses strict mode, see `Finding elements` for more details about strict mode.
 
@@ -165,6 +150,8 @@ class Waiter(LibraryComponent):
         | ${promise}      `Promise To`      `Wait For Function`    element => element.style.width=="100%"    selector=\\#progress_bar    timeout=4s
         | `Click`         \\#progress_bar
         | `Wait For`      ${promise}
+
+        [https://forum.robotframework.org/t//4346|Comment >>]
         """
         timeout_as_str = self.millisecs_to_timestr(self.get_timeout(timeout))
         end = float(
@@ -212,3 +199,54 @@ class Waiter(LibraryComponent):
             )
             logger.debug(response.json)
             logger.info(response.log)
+
+    @keyword(tags=("Wait", "PageContent"))
+    def wait_for_condition(
+        self,
+        condition: ConditionInputs,
+        *args: Any,
+        timeout: Optional[timedelta] = None,
+    ) -> Any:
+        """Waits for a condition, defined with Browser getter keywords to become True.
+
+        This Keyword is basically just a wrapper around our assertion keywords, but with a timeout.
+        It can be used to wait for anything that also can be asserted with our keywords.
+
+        In comparison to Robot Frameworks `Wait Until Keywords Succeeds` this keyword is more
+        readable and easier to use but is limited to Browser libraries assertion keywords.
+
+        | =Arguments= | =Description= |
+        | ``condition`` | A condition, defined with Browser getter keywords, without the word ``Get``. |
+        | ``*args`` | Arguments to pass to the condition keyword. |
+        | ``timeout`` | Timout to wait for the condition to become True. Uses default timeout of the library if not set. |
+
+
+
+        The easiest way to use this keyword is first starting with an assertion keyword with assertion like: `Get Text`
+
+        Start:
+        | `Get Text`    id=status_bar   contains    Done
+
+        Then you replace the word `Get` with `Wait For Condition    ` and if necessary add the timeout argument.
+
+        End:
+        | `Wait For Condition`    Text    id=status_bar   contains    Done
+
+
+        Example usage:
+        | `Wait For Condition`    Element States    id=cdk-overlay-0    ==    detached
+        | `Wait For Condition`    Element States     //h1    contains    visible    editable    enabled    timeout=2 s
+        | `Wait For Condition`    Title    should start with    Robot
+        | `Wait For Condition`    Url    should end with    robotframework.org
+
+        [https://forum.robotframework.org/t//4346|Comment >>]
+        """
+        if isinstance(timeout, timedelta):
+            assertion_timeout = self.library.convert_timeout(timeout)
+        else:
+            assertion_timeout = self.timeout
+        original_assert_retry = self.retry_assertions_for_stack.set(assertion_timeout)
+        try:
+            return BuiltIn().run_keyword(condition.value, *args)
+        finally:
+            self.retry_assertions_for_stack.set(original_assert_retry)
